package pps.core.base.service;

import cn.hutool.core.collection.CollUtil;
import cn.hutool.core.date.DateTime;
import cn.hutool.core.date.DateUtil;
import pps.cloud.base.service.IThirdWindPowerGenerationCloudService;
import pps.core.base.entity.ThirdWindPowerGenerationView;
import pps.core.base.mapper.ThirdWindPowerGenerationViewMapper;
import pps.core.base.service.data.config_oil_field.GetConfigOilFieldOutput;
import pps.core.common.utils.BaseUtils;
import xstartup.annotation.XService;
import xstartup.base.XContext;
import xstartup.data.XServiceResult;
import xstartup.data.XSingleResult;

import java.util.List;

/**
 * 第三方风力发电数据
 *
 * @author ZWT
 * @date 2024/09/03 16:34
 */
@XService
public class ThirdWindPowerGenerationCloudServiceImpl implements IThirdWindPowerGenerationCloudService {

    /**
     * 第三方风力发电数据定时任务
     * todo 模拟数据生成
     *
     * @param context 上下文
     * @return {@link XServiceResult }
     */
    @Override
    public XServiceResult thirdWindPowerGenerationJob(XContext context) {
        DateTime endTime = DateUtil.date();
        DateTime startTime = DateUtil.offsetMinute(endTime, -30);
        ThirdWindPowerGenerationViewMapper viewMapper = context.getBean(ThirdWindPowerGenerationViewMapper.class);
        List<ThirdWindPowerGenerationView> list = viewMapper.generateSimulatedData(ThirdWindPowerGenerationView.builder()
                .startTime(startTime)
                .endTime(endTime)
                .build());
        if (CollUtil.isNotEmpty(list)) {
            //查当前环境
            XSingleResult<GetConfigOilFieldOutput> result = context.getBean(ConfigOilFieldService.class).getCurrentConfig(context);
            result.throwIfFail();
            String systemSource = result.getResult().getOilFieldCode();
            for (ThirdWindPowerGenerationView thirdWindPowerGenerationView : list) {
                thirdWindPowerGenerationView.setSystemSource(systemSource);
                thirdWindPowerGenerationView.setInputTime(endTime);
            }
            //批量新增
            if (list.size() > BaseUtils.BATCH_SIZE) {
                List<List<ThirdWindPowerGenerationView>> subList = BaseUtils.getSubList(list);
                subList.forEach(viewMapper::batchInsert);
            } else {
                viewMapper.batchInsert(list);
            }
        }
        return XServiceResult.OK;
    }
}
